@@ -278,7 +278,6 @@ class FacileToolkit2:
             errors = ', '.join(not_visible_elements)
             BuiltIn().run_keyword_and_ignore_error("Should Be Empty", errors, "Following elements are not visible: %s" % errors)
 
-    @keyword
     def i_dont_see(self, *locators):
         """
         Loops over an array of locators and checks
@@ -292,6 +291,14 @@ class FacileToolkit2:
             errors = ', '.join(visible_elements)
             BuiltIn().run_keyword_and_ignore_error("Should Be Empty", errors, "Following elements are visible: %s" % errors)
 
+    @keyword(name="I Don't See")
+    def i_don_t_see(self, *locators):
+        """
+        Loops over an array of locators and checks
+        if the webelements represented by them are visible on the page
+        """
+        self.i_dont_see(*locators)
+    
     @keyword
     def select_first_autocomplete_option(self,
                                          locator_option="css:.autocomplete-suggestions:not([style*='display']):not(["
@@ -685,12 +692,14 @@ class FacileToolkit2:
             self.sl.log_location()
             self.sl.close_all_browsers()
 
-    def i_see_elements_label(self, *locators):
+    def i_see_elements_label(self, *locators, timeout=None):
         self.set_selenium_library()
         for locator in locators:
-            BuiltIn().run_keyword_and_continue_on_failure("element_should_be_visible",
-                                                          "css:label[for='%s']" % self.sl.get_element_attribute(locator,
-                                                                                                                "id"))
+            label_locator = "css:label[for='%s']" % self.sl.get_element_attribute(locator, "id")
+            if timeout is None:
+                BuiltIn().run_keyword_and_continue_on_failure("element_should_be_visible", label_locator)
+            else:
+                BuiltIn().run_keyword_and_continue_on_failure("wait_until_element_is_visible", label_locator, timeout)
 
     @keyword
     def close_symfony_toolbar(self, timeout=None):
